from dataclasses import dataclass
from feedancy_client.lib.client import ApiClient
from feedancy_client.lib.configuration import Configuration
from feedancy_client.lib.adapter.base import HttpClientAdapter


from .apis.activitysphere.api import ActivitysphereApi

from .apis.city.api import CityApi

from .apis.company.api import CompanyApi

from .apis.companycity.api import CompanycityApi

from .apis.contact.api import ContactApi

from .apis.country.api import CountryApi

from .apis.currency.api import CurrencyApi

from .apis.internship.api import InternshipApi

from .apis.internshipcity.api import InternshipcityApi

from .apis.internshipcontact.api import InternshipcontactApi

from .apis.internshipskill.api import InternshipskillApi

from .apis.jobmixin.api import JobmixinApi

from .apis.region.api import RegionApi

from .apis.salary.api import SalaryApi

from .apis.searchandstopkeywords.api import SearchandstopkeywordsApi

from .apis.searchkeywords.api import SearchkeywordsApi

from .apis.skill.api import SkillApi

from .apis.source.api import SourceApi

from .apis.stopkeywords.api import StopkeywordsApi

from .apis.vacancy.api import VacancyApi

from .apis.vacancycity.api import VacancycityApi

from .apis.vacancycontact.api import VacancycontactApi

from .apis.vacancyskill.api import VacancyskillApi



@dataclass
class AutogeneratedApiClient:
    configuration: Configuration
    client: ApiClient
    activitysphere: ActivitysphereApi
    city: CityApi
    company: CompanyApi
    companycity: CompanycityApi
    contact: ContactApi
    country: CountryApi
    currency: CurrencyApi
    internship: InternshipApi
    internshipcity: InternshipcityApi
    internshipcontact: InternshipcontactApi
    internshipskill: InternshipskillApi
    jobmixin: JobmixinApi
    region: RegionApi
    salary: SalaryApi
    searchandstopkeywords: SearchandstopkeywordsApi
    searchkeywords: SearchkeywordsApi
    skill: SkillApi
    source: SourceApi
    stopkeywords: StopkeywordsApi
    vacancy: VacancyApi
    vacancycity: VacancycityApi
    vacancycontact: VacancycontactApi
    vacancyskill: VacancyskillApi


def new_client(
    adapter: HttpClientAdapter, configuration: Configuration
) -> AutogeneratedApiClient:
    client = ApiClient(configuration=configuration, adapter=adapter)
    return AutogeneratedApiClient(
        configuration,
        client=client,
        
        activitysphere=ActivitysphereApi(client, configuration),
        
        city=CityApi(client, configuration),
        
        company=CompanyApi(client, configuration),
        
        companycity=CompanycityApi(client, configuration),
        
        contact=ContactApi(client, configuration),
        
        country=CountryApi(client, configuration),
        
        currency=CurrencyApi(client, configuration),
        
        internship=InternshipApi(client, configuration),
        
        internshipcity=InternshipcityApi(client, configuration),
        
        internshipcontact=InternshipcontactApi(client, configuration),
        
        internshipskill=InternshipskillApi(client, configuration),
        
        jobmixin=JobmixinApi(client, configuration),
        
        region=RegionApi(client, configuration),
        
        salary=SalaryApi(client, configuration),
        
        searchandstopkeywords=SearchandstopkeywordsApi(client, configuration),
        
        searchkeywords=SearchkeywordsApi(client, configuration),
        
        skill=SkillApi(client, configuration),
        
        source=SourceApi(client, configuration),
        
        stopkeywords=StopkeywordsApi(client, configuration),
        
        vacancy=VacancyApi(client, configuration),
        
        vacancycity=VacancycityApi(client, configuration),
        
        vacancycontact=VacancycontactApi(client, configuration),
        
        vacancyskill=VacancyskillApi(client, configuration)
        
    )